package com.example.demo.order.service.impl;

import cn.hutool.core.util.IdUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.demo.common.utils.DateUtils;
import com.example.demo.common.utils.RedisUtil;
import com.example.demo.common.utils.TokenUtils;
import com.example.demo.coupon.dao.CouponMapper;
import com.example.demo.coupon.dao.UserCouponMapper;
import com.example.demo.coupon.domain.UserCoupon;
import com.example.demo.order.dao.OrderItemMapper;
import com.example.demo.order.domain.OrderInfo;
import com.example.demo.order.domain.OrderItem;
import com.example.demo.order.dto.OrderInfoDto;
import com.example.demo.order.dto.OrderInfoUpDto;
import com.example.demo.order.dto.OrderItemDto;
import com.example.demo.order.service.OrderInfoService;
import com.example.demo.order.dao.OrderInfoMapper;
import com.example.demo.product.dao.ProductMapper;
import com.example.demo.product.domain.Product;
import com.example.demo.user.vo.ResultVo;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;
import java.util.Map;
import java.util.HashMap;

/**
* @author 徐乐
* @description 针对表【order_info(订单主表)】的数据库操作Service实现
* @createDate 2025-06-17 19:27:10
*/
@Service
public class OrderInfoServiceImpl extends ServiceImpl<OrderInfoMapper, OrderInfo>
    implements OrderInfoService{

    private static final Logger log = LoggerFactory.getLogger(OrderInfoServiceImpl.class);

    @Autowired
    private OrderInfoMapper orderInfoMapper;
    @Autowired
    private OrderItemMapper orderItemMapper;
    @Autowired
    private ProductMapper productMapper;
    @Autowired
    private RedisUtil redisUtil;
    @Autowired
    private UserCouponMapper userCouponMapper;
    @Autowired
    private CouponMapper couponMapper;

    @Override
    public ResultVo orderAdd(OrderInfoDto dto, String token) {
        Long userId = TokenUtils.getUserId(token);
        if (userId==null){
            return ResultVo.error(101,"请先登录");
        }
        OrderInfo orderInfo = new OrderInfo();
        orderInfo.setId(IdUtil.getSnowflake().nextId());
        String yyMMddHHmmss = DateUtils.getDateTimeNum();
        String startNum = redisUtil.getStartNum(yyMMddHHmmss);
        //订单编号
        String orderNo = yyMMddHHmmss + startNum;
        orderInfo.setOrderNo(orderNo);
        orderInfo.setUserId(userId);
        //总金额
        BigDecimal totalAmount = BigDecimal.ZERO;
        //优惠金额
        BigDecimal discountAmount = BigDecimal.ZERO;
        //实付金额
        BigDecimal actualAmount = BigDecimal.ZERO;
        List<OrderItemDto> orderItemDtoList = dto.getOrderItemDtos();
        List<OrderItem> orderItemList = new ArrayList<>();
        for (OrderItemDto orderItemDto : orderItemDtoList) {
            OrderItem orderItem = new OrderItem();
            orderItem.setId(IdUtil.getSnowflake().nextId());
            orderItem.setOrderId(orderInfo.getId());
            System.err.println(orderItem.getOrderId());
            Product product = productMapper.selectById(orderItemDto.getProductId());
            if (product.getStock()==0){
                return ResultVo.error(102,"商品已售罄");
            }
            orderItem.setProductId(product.getId());
            orderItem.setProductName(product.getTitle());
            orderItem.setPrice(product.getPrice());
            product.setStock(product.getStock()-orderItemDto.getQuantity());
            orderItem.setQuantity(orderItemDto.getQuantity());
            orderItem.setItemAmount(orderItem.getPrice().multiply(new BigDecimal(orderItemDto.getQuantity())));
            totalAmount = totalAmount.add(orderItem.getItemAmount());
            QueryWrapper<UserCoupon> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("coupon_id",orderItemDto.getCouponId());
            UserCoupon userCoupon = userCouponMapper.selectOne(queryWrapper);
            orderInfo.setUserCouponId(userCoupon.getId());
            orderItem.setCouponId(userCoupon.getCouponId());
            orderItem.setDiscountAmount(userCoupon.getAmount());
            userCoupon.setUseTime(new Date());
            userCoupon.setStatus(2);
            discountAmount = discountAmount.add(orderItem.getDiscountAmount());
            orderItem.setPayAmount(orderItem.getItemAmount().subtract(orderItem.getDiscountAmount()));
            actualAmount = actualAmount.add(orderItem.getPayAmount());
            orderItemList.add(orderItem);
            productMapper.updateById(product);
            userCouponMapper.updateById(userCoupon);
        }
        orderInfo.setTotalAmount(totalAmount);
        orderInfo.setDiscountAmount(discountAmount);
        orderInfo.setActualAmount(actualAmount);
        orderInfo.setPaymentMethod(dto.getPaymentMethod());
        orderInfoMapper.insert(orderInfo);
        for (OrderItem orderItem : orderItemList) {
            orderItemMapper.insert(orderItem);
        }
        return ResultVo.success("订单创建成功");
    }

    @Override
    public ResultVo orderUp(OrderInfoUpDto dto, String token) {
        Long userId = TokenUtils.getUserId(token);
        if (userId==null){
            return ResultVo.error(101,"请先登录");
        }
        QueryWrapper<OrderInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("id",dto.getId());
        OrderInfo orderInfo = orderInfoMapper.selectOne(queryWrapper);
        if (orderInfo==null){
            return ResultVo.error(102,"订单不存在");
        }
        orderInfo.setPaymentTime(new Date());
        orderInfo.setOrderStatus(dto.getOrderStatus());
//        orderInfoMapper.updateById(orderInfo);
        return ResultVo.success("订单修改成功");
    }

    @Override
    public ResultVo orderGetList(String token) {
        Long userId = TokenUtils.getUserId(token);
        if (userId==null){
            return ResultVo.error(101,"请先登录");
        }
        QueryWrapper<OrderInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("user_id",userId);
        List<OrderInfo> orderInfoList = orderInfoMapper.selectList(queryWrapper);
        return ResultVo.success(orderInfoList);
    }
    
    @Override
    @Transactional
    public ResultVo orderPay(Long orderId, Integer paymentMethod, String token) {
        // 验证用户身份
        Long userId = TokenUtils.getUserId(token);
        if (userId == null) {
            return ResultVo.error(101, "请先登录");
        }
        
        // 查询订单信息
        OrderInfo orderInfo = orderInfoMapper.selectById(orderId);
        if (orderInfo == null) {
            return ResultVo.error(102, "订单不存在");
        }
        
        // 验证订单归属
        if (!orderInfo.getUserId().equals(userId)) {
            return ResultVo.error(103, "无权操作此订单");
        }
        
        // 检查订单状态
        if (orderInfo.getOrderStatus() != 1) {  // 1是待支付状态
            return ResultVo.error(104, "订单状态不允许支付");
        }
        
        // 获取支付金额
        BigDecimal payAmount = orderInfo.getActualAmount();
        
        // 根据支付方式调用不同的支付接口
        boolean payResult = false;
        
        try {
            // 模拟调用支付接口
            Map<String, Object> payResponse = callPaymentApi(paymentMethod, payAmount, orderInfo.getOrderNo());
            payResult = (boolean) payResponse.get("success");
            
            if (!payResult) {
                return ResultVo.error(105, "支付失败：" + payResponse.get("message"));
            }
            
            // 更新订单状态
            orderInfo.setOrderStatus(2);  // 2是已支付状态
            orderInfo.setPaymentTime(new Date());
            orderInfo.setPaymentMethod(paymentMethod);
            orderInfoMapper.updateById(orderInfo);
            
            // 可以在这里添加其他业务逻辑，如发送通知、更新库存等
            
            return ResultVo.success("支付成功");
        } catch (Exception e) {
            // 记录支付异常
            log.error("订单支付异常: orderId={}, error={}", orderId, e.getMessage(), e);
            return ResultVo.error(106, "支付处理异常：" + e.getMessage());
        }
    }
    
    /**
     * 模拟调用支付API
     * 
     * @param paymentMethod 支付方式：1-微信支付 3-银行卡
     * @param amount 支付金额
     * @param orderNo 订单编号
     * @return 支付结果
     */
    private Map<String, Object> callPaymentApi(Integer paymentMethod, BigDecimal amount, String orderNo) {
        // 这里模拟支付过程，实际项目中应该调用真实的支付接口
        Map<String, Object> result = new HashMap<>();
        
        // 模拟成功率95%
        boolean isSuccess = Math.random() > 0.05;
        
        if (isSuccess) {
            result.put("success", true);
            result.put("paymentNo", "PAY" + System.currentTimeMillis());
            result.put("message", "支付成功");
        } else {
            result.put("success", false);
            result.put("message", "支付失败，请重试");
        }
        
        return result;
    }
}




