package com.example.demo.scenic_spot.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import java.math.BigDecimal;
import java.util.Date;
import lombok.Data;

/**
 * 景点信息表
 * @TableName scenic_spot
 */
@TableName(value ="scenic_spot")
@Data
public class ScenicSpot {
    /**
     * 景点ID
     */
    @TableId(type = IdType.AUTO)
    private Long id;

    /**
     * 景点名称
     */
    private String name;

    /**
     * 景点拼音，用于拼音搜索
     */
    private String pinyin;

    /**
     * 景点描述
     */
    private String description;

    /**
     * 详细地址
     */
    private String address;

    /**
     * 所在城市
     */
    private String city;

    /**
     * 所在区县
     */
    private String district;

    /**
     * 经度（字符串格式）
     */
    private String longitudeStr;

    /**
     * 纬度（字符串格式）
     */
    private String latitudeStr;

    /**
     * 景点类型
     */
    private String category;

    /**
     * 景区等级
     */
    private String level;

    /**
     * 封面图片
     */
    private String coverImage;

    /**
     * 门票价格
     */
    private BigDecimal ticketPrice;

    /**
     * 优惠价格
     */
    private BigDecimal discountPrice;

    /**
     * 开放时间描述
     */
    private String openTime;

    /**
     * 营业时间（开始）
     */
    private Date openTimeStart;

    /**
     * 营业时间（结束）
     */
    private Date openTimeEnd;

    /**
     * 建议游玩时长（分钟）
     */
    private Integer recommendedTime;

    /**
     * 联系电话
     */
    private String contactPhone;

    /**
     * 官方网站
     */
    private String website;

    /**
     * 平均评分
     */
    private BigDecimal avgRating;

    /**
     * 是否热门景点
     */
    private Integer isHot;

    /**
     * 是否推荐景点
     */
    private Integer isRecommended;

    /**
     * 状态
     */
    private String status;

    /**
     * 景点标签，多个用逗号分隔
     */
    private String tags;

    /**
     * 创建人ID
     */
    private Long createdBy;

    /**
     * 创建时间
     */
    private Date createdTime;

    /**
     * 更新人ID
     */
    private Long updatedBy;

    /**
     * 更新时间
     */
    private Date updatedTime;

    /**
     * 是否删除 0:否 1:是
     */
    private Integer isDeleted;

    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ScenicSpot other = (ScenicSpot) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getName() == null ? other.getName() == null : this.getName().equals(other.getName()))
            && (this.getPinyin() == null ? other.getPinyin() == null : this.getPinyin().equals(other.getPinyin()))
            && (this.getDescription() == null ? other.getDescription() == null : this.getDescription().equals(other.getDescription()))
            && (this.getAddress() == null ? other.getAddress() == null : this.getAddress().equals(other.getAddress()))
            && (this.getCity() == null ? other.getCity() == null : this.getCity().equals(other.getCity()))
            && (this.getDistrict() == null ? other.getDistrict() == null : this.getDistrict().equals(other.getDistrict()))
            && (this.getLongitudeStr() == null ? other.getLongitudeStr() == null : this.getLongitudeStr().equals(other.getLongitudeStr()))
            && (this.getLatitudeStr() == null ? other.getLatitudeStr() == null : this.getLatitudeStr().equals(other.getLatitudeStr()))
            && (this.getCategory() == null ? other.getCategory() == null : this.getCategory().equals(other.getCategory()))
            && (this.getLevel() == null ? other.getLevel() == null : this.getLevel().equals(other.getLevel()))
            && (this.getCoverImage() == null ? other.getCoverImage() == null : this.getCoverImage().equals(other.getCoverImage()))
            && (this.getTicketPrice() == null ? other.getTicketPrice() == null : this.getTicketPrice().equals(other.getTicketPrice()))
            && (this.getDiscountPrice() == null ? other.getDiscountPrice() == null : this.getDiscountPrice().equals(other.getDiscountPrice()))
            && (this.getOpenTime() == null ? other.getOpenTime() == null : this.getOpenTime().equals(other.getOpenTime()))
            && (this.getOpenTimeStart() == null ? other.getOpenTimeStart() == null : this.getOpenTimeStart().equals(other.getOpenTimeStart()))
            && (this.getOpenTimeEnd() == null ? other.getOpenTimeEnd() == null : this.getOpenTimeEnd().equals(other.getOpenTimeEnd()))
            && (this.getRecommendedTime() == null ? other.getRecommendedTime() == null : this.getRecommendedTime().equals(other.getRecommendedTime()))
            && (this.getContactPhone() == null ? other.getContactPhone() == null : this.getContactPhone().equals(other.getContactPhone()))
            && (this.getWebsite() == null ? other.getWebsite() == null : this.getWebsite().equals(other.getWebsite()))
            && (this.getAvgRating() == null ? other.getAvgRating() == null : this.getAvgRating().equals(other.getAvgRating()))
            && (this.getIsHot() == null ? other.getIsHot() == null : this.getIsHot().equals(other.getIsHot()))
            && (this.getIsRecommended() == null ? other.getIsRecommended() == null : this.getIsRecommended().equals(other.getIsRecommended()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getTags() == null ? other.getTags() == null : this.getTags().equals(other.getTags()))
            && (this.getCreatedBy() == null ? other.getCreatedBy() == null : this.getCreatedBy().equals(other.getCreatedBy()))
            && (this.getCreatedTime() == null ? other.getCreatedTime() == null : this.getCreatedTime().equals(other.getCreatedTime()))
            && (this.getUpdatedBy() == null ? other.getUpdatedBy() == null : this.getUpdatedBy().equals(other.getUpdatedBy()))
            && (this.getUpdatedTime() == null ? other.getUpdatedTime() == null : this.getUpdatedTime().equals(other.getUpdatedTime()))
            && (this.getIsDeleted() == null ? other.getIsDeleted() == null : this.getIsDeleted().equals(other.getIsDeleted()));
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getName() == null) ? 0 : getName().hashCode());
        result = prime * result + ((getPinyin() == null) ? 0 : getPinyin().hashCode());
        result = prime * result + ((getDescription() == null) ? 0 : getDescription().hashCode());
        result = prime * result + ((getAddress() == null) ? 0 : getAddress().hashCode());
        result = prime * result + ((getCity() == null) ? 0 : getCity().hashCode());
        result = prime * result + ((getDistrict() == null) ? 0 : getDistrict().hashCode());
        result = prime * result + ((getLongitudeStr() == null) ? 0 : getLongitudeStr().hashCode());
        result = prime * result + ((getLatitudeStr() == null) ? 0 : getLatitudeStr().hashCode());
        result = prime * result + ((getCategory() == null) ? 0 : getCategory().hashCode());
        result = prime * result + ((getLevel() == null) ? 0 : getLevel().hashCode());
        result = prime * result + ((getCoverImage() == null) ? 0 : getCoverImage().hashCode());
        result = prime * result + ((getTicketPrice() == null) ? 0 : getTicketPrice().hashCode());
        result = prime * result + ((getDiscountPrice() == null) ? 0 : getDiscountPrice().hashCode());
        result = prime * result + ((getOpenTime() == null) ? 0 : getOpenTime().hashCode());
        result = prime * result + ((getOpenTimeStart() == null) ? 0 : getOpenTimeStart().hashCode());
        result = prime * result + ((getOpenTimeEnd() == null) ? 0 : getOpenTimeEnd().hashCode());
        result = prime * result + ((getRecommendedTime() == null) ? 0 : getRecommendedTime().hashCode());
        result = prime * result + ((getContactPhone() == null) ? 0 : getContactPhone().hashCode());
        result = prime * result + ((getWebsite() == null) ? 0 : getWebsite().hashCode());
        result = prime * result + ((getAvgRating() == null) ? 0 : getAvgRating().hashCode());
        result = prime * result + ((getIsHot() == null) ? 0 : getIsHot().hashCode());
        result = prime * result + ((getIsRecommended() == null) ? 0 : getIsRecommended().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getTags() == null) ? 0 : getTags().hashCode());
        result = prime * result + ((getCreatedBy() == null) ? 0 : getCreatedBy().hashCode());
        result = prime * result + ((getCreatedTime() == null) ? 0 : getCreatedTime().hashCode());
        result = prime * result + ((getUpdatedBy() == null) ? 0 : getUpdatedBy().hashCode());
        result = prime * result + ((getUpdatedTime() == null) ? 0 : getUpdatedTime().hashCode());
        result = prime * result + ((getIsDeleted() == null) ? 0 : getIsDeleted().hashCode());
        return result;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", name=").append(name);
        sb.append(", pinyin=").append(pinyin);
        sb.append(", description=").append(description);
        sb.append(", address=").append(address);
        sb.append(", city=").append(city);
        sb.append(", district=").append(district);
        sb.append(", longitudeStr=").append(longitudeStr);
        sb.append(", latitudeStr=").append(latitudeStr);
        sb.append(", category=").append(category);
        sb.append(", level=").append(level);
        sb.append(", coverImage=").append(coverImage);
        sb.append(", ticketPrice=").append(ticketPrice);
        sb.append(", discountPrice=").append(discountPrice);
        sb.append(", openTime=").append(openTime);
        sb.append(", openTimeStart=").append(openTimeStart);
        sb.append(", openTimeEnd=").append(openTimeEnd);
        sb.append(", recommendedTime=").append(recommendedTime);
        sb.append(", contactPhone=").append(contactPhone);
        sb.append(", website=").append(website);
        sb.append(", avgRating=").append(avgRating);
        sb.append(", isHot=").append(isHot);
        sb.append(", isRecommended=").append(isRecommended);
        sb.append(", status=").append(status);
        sb.append(", tags=").append(tags);
        sb.append(", createdBy=").append(createdBy);
        sb.append(", createdTime=").append(createdTime);
        sb.append(", updatedBy=").append(updatedBy);
        sb.append(", updatedTime=").append(updatedTime);
        sb.append(", isDeleted=").append(isDeleted);
        sb.append("]");
        return sb.toString();
    }
}