package com.example.demo.scenic_spot.service.impl;

import cn.easyes.core.biz.EsPageInfo;
import cn.easyes.core.conditions.LambdaEsQueryWrapper;
import cn.hutool.core.util.IdUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.demo.common.utils.HttpUtils;
import com.example.demo.common.utils.TokenUtils;
import com.example.demo.scenic_spot.domain.ScenicSpot;
import com.example.demo.scenic_spot.dto.ScenicSpotDto;
import com.example.demo.scenic_spot.entity.ScenicSpotEntity;
import com.example.demo.scenic_spot.esmapper.ScenicSpotEsMapper;
import com.example.demo.scenic_spot.service.ScenicSpotService;
import com.example.demo.scenic_spot.dao.ScenicSpotMapper;
import com.example.demo.user.vo.ResultVo;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.util.EntityUtils;
import org.elasticsearch.client.indices.GetIndexResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
* @author 徐乐
* @description 针对表【scenic_spot(景点信息表)】的数据库操作Service实现
* @createDate 2025-06-17 14:17:18
*/
@Service
public class ScenicSpotServiceImpl extends ServiceImpl<ScenicSpotMapper, ScenicSpot>
    implements ScenicSpotService{

    @Autowired
    private ScenicSpotEsMapper scenicSpotEsMapper;
    @Override
    public ResultVo syncDataToEs() {

        //创建索引
        scenicSpotEsMapper.createIndex();
        List<ScenicSpot> scenicSpotList = this.list();
        List<ScenicSpotEntity> scenicSpotEntityList = new ArrayList<>();
        for (ScenicSpot scenicSpot : scenicSpotList) {
            ScenicSpotEntity scenicSpotEntity = new ScenicSpotEntity();
            scenicSpotEntity.setId(scenicSpot.getId());
            scenicSpotEntity.setName(scenicSpot.getName());
            scenicSpotEntity.setPinyin(scenicSpot.getPinyin());
            scenicSpotEntity.setDescription(scenicSpot.getDescription());
            scenicSpotEntity.setAddress(scenicSpot.getAddress());
            scenicSpotEntity.setCity(scenicSpot.getCity());
            scenicSpotEntity.setDistrict(scenicSpot.getDistrict());
            scenicSpotEntity.setLongitudeStr(scenicSpot.getLongitudeStr());
            scenicSpotEntity.setLatitudeStr(scenicSpot.getLatitudeStr());
            scenicSpotEntity.setCategory(scenicSpot.getCategory());
            scenicSpotEntity.setLevel(scenicSpot.getLevel());
            scenicSpotEntity.setCoverImage(scenicSpot.getCoverImage());
            scenicSpotEntity.setTicketPrice(scenicSpot.getTicketPrice());
            scenicSpotEntity.setDiscountPrice(scenicSpot.getDiscountPrice());
            scenicSpotEntity.setOpenTime(scenicSpot.getOpenTime());
            scenicSpotEntity.setOpenTimeStart(scenicSpot.getOpenTimeStart());
            scenicSpotEntity.setOpenTimeEnd(scenicSpot.getOpenTimeEnd());
            scenicSpotEntity.setRecommendedTime(scenicSpot.getRecommendedTime());
            scenicSpotEntity.setContactPhone(scenicSpot.getContactPhone());
            scenicSpotEntity.setWebsite(scenicSpot.getWebsite());
            scenicSpotEntity.setIsHot(scenicSpot.getIsHot());
            scenicSpotEntity.setIsRecommended(scenicSpot.getIsRecommended());
            scenicSpotEntity.setStatus(scenicSpot.getStatus());
            scenicSpotEntity.setTags(scenicSpot.getTags());
            scenicSpotEntity.setCreatedBy(scenicSpot.getCreatedBy());
            scenicSpotEntity.setCreatedTime(scenicSpot.getCreatedTime());
            scenicSpotEntity.setUpdatedBy(scenicSpot.getUpdatedBy());
            scenicSpotEntity.setUpdatedTime(scenicSpot.getUpdatedTime());
            scenicSpotEntity.setIsDeleted(scenicSpot.getIsDeleted());
            scenicSpotEntityList.add(scenicSpotEntity);
        }
        scenicSpotEsMapper.insertBatch(scenicSpotEntityList, "scenic_spot");
        return ResultVo.success("数据同步成功");
    }

    @Override
    public ResultVo getScenicSpotList(String token, HttpResponse response, String keyword) {
        Long userId = TokenUtils.getUserId(token);
        if (userId==null){
            return ResultVo.error(101,"请先登录");
        }
        String host = "https://ali-spot.showapi.com";
        String path = "/spotList";
        String method = "GET";
        String appcode = "a1595e6d28984e07ba4f939fa53ccb55";
        Map<String, String> headers = new HashMap<String, String>();
        //最后在header中的格式(中间是英文空格)为Authorization:APPCODE 83359fd73fe94948385f570e3c139105
        headers.put("Authorization", "APPCODE " + appcode);
        Map<String, String> querys = new HashMap<String, String>();
        querys.put("keyword", keyword);
//        querys.put("proId", "proId");
//        querys.put("cityId", "cityId");
//        querys.put("areaId", "areaId");
//        querys.put("page", "page");


        try {
            /**
             * 重要提示如下:
             * HttpUtils请从
             * https://github.com/aliyun/api-gateway-demo-sign-java/blob/master/src/main/java/com/aliyun/api/gateway/demo/util/HttpUtils.java
             * 下载
             *
             * 相应的依赖请参照
             * https://github.com/aliyun/api-gateway-demo-sign-java/blob/master/pom.xml
             */
            HttpResponse response1 = HttpUtils.doGet(host, path, method, headers, querys);
            System.out.println(response1.toString());
            //获取response的body
//            System.out.println(EntityUtils.toString(response.getEntity()));
            // 获取响应体内容，注意处理异常
            String responseBody = EntityUtils.toString(response1.getEntity(), "UTF-8");
            // 打印响应体，方便调试查看
            System.out.println("接口返回数据：" + responseBody);

            // 解析响应体（这里假设返回的是 JSON 格式，根据实际情况调整解析逻辑）
            // 如果是 JSON 字符串，转成 JSONObject 或者 Java 实体类
            JSONObject resultJson = JSON.parseObject(responseBody);
            // 假设你的 ResultVo 的 obj 字段可以接收解析后的 JSON 数据或者 Map 等
            return ResultVo.success(resultJson);
        } catch (Exception e) {
            e.printStackTrace();
            return ResultVo.error();
        }
    }
}




