package com.example.demo.user.service.impl;

import cn.hutool.core.util.IdUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.demo.common.utils.TokenUtils;
import com.example.demo.user.domain.UserFavorite;
import com.example.demo.user.dto.CollectDto;
import com.example.demo.user.service.UserFavoriteService;
import com.example.demo.user.dao.UserFavoriteMapper;
import com.example.demo.user.vo.ResultVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
* @author 徐乐
* @description 针对表【user_favorite(用户收藏记录表)】的数据库操作Service实现
* @createDate 2025-06-24 18:47:01
*/
@Service
public class UserFavoriteServiceImpl extends ServiceImpl<UserFavoriteMapper, UserFavorite>
    implements UserFavoriteService{
    @Autowired
    private UserFavoriteMapper userFavoriteMapper;

    @Override
    public ResultVo collect(CollectDto dto, String token) {
        Long userId = TokenUtils.getUserId(token);
        if (userId==null){
            return ResultVo.error(101,"请先登录");
        }
        UserFavorite favorite = new UserFavorite();
        favorite.setId(IdUtil.getSnowflake().nextId());
        favorite.setUserId(userId);
        favorite.setTargetType(dto.getTargetType());
        favorite.setTargetId(dto.getTargetId());
        favorite.setCreateTime(new Date());
        userFavoriteMapper.insert(favorite);
        return ResultVo.success("用户收藏成功");
    }

    @Override
    public ResultVo delCollect(Integer targetId, String token) {
        Long userId = TokenUtils.getUserId(token);
        if (userId==null){
            return ResultVo.error(101,"请先登录");
        }
        QueryWrapper<UserFavorite> wrapper = new QueryWrapper<>();
        wrapper.eq("target_id",targetId);
        userFavoriteMapper.delete(wrapper);
        return ResultVo.success("用户取消收藏成功");
    }

    @Override
    public ResultVo selCollect(String token) {
        Long userId = TokenUtils.getUserId(token);
        if (userId==null){
            return ResultVo.error(101,"请先登录");
        }
        QueryWrapper<UserFavorite> wrapper = new QueryWrapper<>();
        List<UserFavorite> favoriteList = userFavoriteMapper.selectList(wrapper);
        return ResultVo.success(favoriteList);
    }

}




